@@ -17,6 +17,6 @@ Options:
 from type_docopt import docopt
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     arguments = docopt(__doc__)
     print(arguments)
