@@ -29,5 +29,5 @@ Specific git-branch actions:
 from type_docopt import docopt
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     print(docopt(__doc__))
