@@ -23,5 +23,5 @@
 from type_docopt import docopt
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     print(docopt(__doc__))
